from io import open
from setuptools import setup


setup(
    name='arucodetect',
    version='1.1',
    author='myortf_inside',
    author_email='faridgarifullin66@gmail.com',

    packages=['arucodetect'],
    install_requires = ['opencv-python']
)